"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeDepsCmd = void 0;
const package_url_1 = require("../domain/package-url");
const package_reference_1 = require("../domain/package-reference");
const common_errors_1 = require("../common-errors");
const dependency_logging_1 = require("./dependency-logging");
const packument_1 = require("../domain/packument");
const result_codes_1 = require("./result-codes");
const error_logging_1 = require("./error-logging");
function errorPrefixForError(error) {
    if (error instanceof common_errors_1.PackumentNotFoundError)
        return "missing dependency";
    else if (error instanceof packument_1.VersionNotFoundError)
        return "missing dependency version";
    return "unknown";
}
/**
 * Makes a {@link DepsCmd} function.
 */
function makeDepsCmd(parseEnv, resolveDependencies, log, debugLog) {
    return async (pkg, options) => {
        // parse env
        const envResult = await parseEnv(options);
        if (envResult.isErr()) {
            (0, error_logging_1.notifyEnvParsingFailed)(log, envResult.error);
            return result_codes_1.ResultCodes.Error;
        }
        const env = envResult.value;
        const [name, version] = (0, package_reference_1.splitPackageReference)(pkg);
        if (version !== undefined && (0, package_url_1.isPackageUrl)(version)) {
            log.error("", "cannot get dependencies for url-version");
            return result_codes_1.ResultCodes.Error;
        }
        const deep = options.deep || false;
        debugLog(`fetch: ${(0, package_reference_1.makePackageReference)(name, version)}, deep=${deep}`);
        const resolveResult = await resolveDependencies([env.registry, env.upstreamRegistry], name, version, deep);
        if (resolveResult.isErr()) {
            (0, error_logging_1.notifyRemotePackumentVersionResolvingFailed)(log, name, resolveResult.error);
            return result_codes_1.ResultCodes.Error;
        }
        const [depsValid, depsInvalid] = resolveResult.value;
        depsValid.forEach((dependency) => (0, dependency_logging_1.logValidDependency)(debugLog, dependency));
        depsValid
            .filter((x) => !x.self)
            .forEach((x) => log.notice("dependency", `${(0, package_reference_1.makePackageReference)(x.name, x.version)}`));
        depsInvalid
            .filter((x) => !x.self)
            .forEach((x) => {
            const prefix = errorPrefixForError(x.reason);
            log.warn(prefix, x.name);
        });
        return result_codes_1.ResultCodes.Ok;
    };
}
exports.makeDepsCmd = makeDepsCmd;
//# sourceMappingURL=cmd-deps.js.map