"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeLoginCmd = void 0;
const registry_url_1 = require("../domain/registry-url");
const prompts_1 = require("./prompts");
const result_codes_1 = require("./result-codes");
const common_errors_1 = require("../io/common-errors");
const error_logging_1 = require("./error-logging");
/**
 * Makes a {@link LoginCmd} function.
 */
function makeLoginCmd(parseEnv, getUpmConfigPath, login, log) {
    return async (options) => {
        // parse env
        const envResult = await parseEnv(options);
        if (envResult.isErr()) {
            (0, error_logging_1.notifyEnvParsingFailed)(log, envResult.error);
            return result_codes_1.ResultCodes.Error;
        }
        const env = envResult.value;
        // query parameters
        const username = options.username ?? (await (0, prompts_1.promptUsername)());
        const password = options.password ?? (await (0, prompts_1.promptPassword)());
        const email = options.email ?? (await (0, prompts_1.promptEmail)());
        const loginRegistry = options._global.registry !== undefined
            ? (0, registry_url_1.coerceRegistryUrl)(options._global.registry)
            : await (0, prompts_1.promptRegistryUrl)();
        const alwaysAuth = options.alwaysAuth || false;
        const configPathResult = await getUpmConfigPath(env.wsl, env.systemUser)
            .promise;
        if (configPathResult.isErr()) {
            // TODO: Log error
            return result_codes_1.ResultCodes.Error;
        }
        const configPath = configPathResult.value;
        const loginResult = await login(username, password, email, alwaysAuth, loginRegistry, configPath, options.basicAuth ? "basic" : "token").promise;
        if (loginResult.isErr()) {
            const loginError = loginResult.error;
            if (loginError instanceof common_errors_1.RegistryAuthenticationError)
                log.warn("401", "Incorrect username or password");
            // TODO: Log all errors
            return result_codes_1.ResultCodes.Error;
        }
        log.notice("auth", `you are authenticated as '${username}'`);
        log.notice("config", "saved unity config at " + configPath);
        return result_codes_1.ResultCodes.Ok;
    };
}
exports.makeLoginCmd = makeLoginCmd;
//# sourceMappingURL=cmd-login.js.map